@@ -134,6 +134,7 @@ class DataPlate:
               async_m=None,
               request_timeout=None,
               es_index_type=None,
+              es_node=None,
               bucket_suffixes=None,
               bucket_filter=None,
               force_scheme_change=False,
@@ -155,7 +156,9 @@ class DataPlate:
             requests timeout parameter for a single request.
             https://requests.readthedocs.io/en/master/user/advanced/#timeouts
         es_index_type: str
-            elasticSearch option - add change dataset index/type for the allowed cluster [e.g.: index1/type1,index2/type2] ,to search for all types in index ignore the type name (default: None)
+            elasticSearch option - dynamically add/change the dataset es.resource (index/type) for the allowed cluster [e.g.: index1/type1,index2/type2] ,to search for all types in index ignore the type name (default: None)
+        es_node: str
+            elasticSearch option - dynamically change host/cluster/node name - use this in case you've defined a regex based es.nodes in the source url of the dataset
         bucket_suffixes: str
             bucket option - bucket path suffix added to your dataset path name, [e.g.: MyPathSuffix1,MyPathSuffix2] (default: None)
         bucket_filter: str
@@ -179,6 +182,8 @@ class DataPlate:
             params['async'] = '1'
         if es_index_type:
             params['es_index_type'] = es_index_type
+        if es_node:
+            params['es_node'] = es_node
         if bucket_suffixes:
             params['bucket_suffixes'] = bucket_suffixes
         if bucket_filter:
@@ -231,6 +236,7 @@ class DataPlate:
                     async_m=None,
                     request_timeout=None,
                     es_index_type=None,
+                    es_node=None,
                     bucket_suffixes=None,
                     bucket_filter=None,
                     force_scheme_change=False,
@@ -253,7 +259,9 @@ class DataPlate:
             requests timeout parameter for a single request.
             https://requests.readthedocs.io/en/master/user/advanced/#timeouts
         es_index_type: str
-            elasticSearch option - add change dataset index/type for the allowed cluster [e.g.: index1/type1,index2/type2] ,to search for all types in index ignore the type name (default: None)
+            elasticSearch option - dynamically add/change the dataset es.resource (index/type) for the allowed cluster [e.g.: index1/type1,index2/type2] ,to search for all types in index ignore the type name (default: None)
+        es_node: str
+            elasticSearch option - dynamically change host/cluster/node name - use this in case you've defined a regex based es.nodes in the source url of the dataset
         bucket_suffixes: str
             bucket option - bucket path suffix added to your dataset path name, [e.g.: MyPathSuffix1,MyPathSuffix2] (default: None)
         bucket_filter: str
@@ -280,7 +288,7 @@ class DataPlate:
         import pandas as pd
         with tempfile.NamedTemporaryFile(suffix='.gz') as t:
             output_file = t.name
-            self.query(query, output_file, refresh, async_m, request_timeout, es_index_type, bucket_suffixes, bucket_filter, force_scheme_change, recursive_lookup_no_partitions)
+            self.query(query, output_file, refresh, async_m, request_timeout, es_index_type, es_node, bucket_suffixes, bucket_filter, force_scheme_change, recursive_lookup_no_partitions)
             with open(output_file, 'rb') as fh:
                 return pd.read_json(fh, compression='gzip', lines=True, **kwargs)
 
